@@ -10,9 +10,9 @@
 # }
 #
 # \usage{
-#  anyMissing(x, ...)
-#  colAnyMissings(x, ...)
-#  rowAnyMissings(x, ...)
+#  @usage anyMissing
+#  @usage colAnyMissings
+#  @usage rowAnyMissings
 # }
 #
 # \arguments{
@@ -52,6 +52,7 @@ anyMissing <- function(x, ...) {
       if (.Call("anyMissing", x[[kk]], PACKAGE="matrixStats"))
         return(TRUE)
     }
+    return(FALSE)
   } else {
     ## All other data types
     .Call("anyMissing", x, PACKAGE="matrixStats")
