@@ -36,5 +36,10 @@ for (mode in modes) {
   print(y)
   stopifnot(identical(dim(y), c(N,3L)))
 
+  y2 <- colTabulates(t(x), values=as.raw(1:3))
+  print(y2)
+  stopifnot(identical(dim(y2), c(N,3L)))
+  stopifnot(identical(y2, y))
+
   cat(sprintf("Mode: %s...done\n", mode))
 } # for (mode ...)
